# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  boot.supportedFilesystems = ["zfs" "ntfs"];
  boot.zfs.requestEncryptionCredentials = true;
  boot.kernelPackages = config.boot.zfs.package.latestCompatibleLinuxPackages;
  #boot.kernelPackages = pkgs.linuxKernel.packages.linux_zen;
  networking.hostId = "78e7d443";
  # networking.hostName = "nixos"; # Define your hostname.
  # networking.wireless.enable = true;  # Enables wireless support via wpa_supplicant.
  networking.networkmanager.enable = true;
  # Set your time zone.
  time.timeZone = "America/New_York";
  services.zfs.autoSnapshot.enable = true;
  services.zfs.autoScrub.enable = true;
  # The global useDHCP flag is deprecated, therefore explicitly set to false here.
  # Per-interface useDHCP will be mandatory in the future, so this generated config
  # replicates the default behaviour.
  #networking.useDHCP = false;
  #networking.interfaces.eno1.useDHCP = true;
  #networking.interfaces.wlp0s20f3.useDHCP = true;
  hardware.bluetooth.enable = true; 
  # Configure network proxy if necessary
  # networking.proxy.default = "http://user:password@proxy:port/";
  # networking.proxy.noProxy = "127.0.0.1,localhost,internal.domain";

  # Select internationalisation properties.
   i18n.defaultLocale = "en_US.UTF-8";
   console = {
     font = "Lat2-Terminus16";
     keyMap = "us";
   };

  # Enable the X11 windowing system.
  services.xserver.enable = true;


  # Enable the Plasma 5 Desktop Environment.
  services.xserver.displayManager.sddm.enable = true;
  services.xserver.desktopManager.plasma5.enable = true;
  

  # Configure keymap in X11
   services.xserver.layout = "us";
  # services.xserver.xkbOptions = "eurosign:e";

  # Enable CUPS to print documents.
  # services.printing.enable = true;
   services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };
  security.rtkit.enable = true;

  # Enable sound.
   sound.enable = false;
   #hardware.pulseaudio.enable = true;

  # Enable touchpad support (enabled default in most desktopManager).
   services.xserver.libinput.enable = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
   users.users.matt = {
     isNormalUser = true;
     extraGroups = [ "wheel" "networkmanager" "kvm" "docker" ]; # Enable ‘sudo’ for the user.
     packages = with pkgs; [
        putty 
        thunderbird
        firefox
        mpv
        vlc
        retroarch
        emacs
        dosbox
        cmus
        gzdoom
        quakespasm
        yquake2
        qbittorrent
        knights
        libreoffice
        ecwolf
        eduke32
        dxx-rebirth
        keepassxc
        openmw
        xonotic
        odamex
        obs-studio
        taskwarrior
        distrobox
        retroshare
        ranger
        okular
        mcomix3
        freenet
        gnunet
        i2p
        strawberry
        enyo-doom
        chocolateDoom
        slade
        focuswriter
        onionshare-gui
        tor-browser-bundle-bin       
     ];

   };
  nixpkgs.config.allowUnfree = true;
  services.flatpak.enable = true;
  services.dbus.enable = true;
  services.cron.enable = true;
  services.gvfs.enable = true;
  programs.steam.enable = true;
  virtualisation.docker = 
  {  enable = true;
    # rootless.enable = true;
  };  

  # List packages installed in system profile. To search, run:
  # $ nix search wget
   #environment.systemPackages = with pkgs; [
   #  vim # Do not forget to add an editor to edit configuration.nix! The Nano editor is also installed by default.
   #  wget
   #  firefox
   #];
  environment.systemPackages =
   [
     pkgs.htop
     pkgs.qemu
     pkgs.exfat
     pkgs.p7zip
     pkgs.sshfs
     pkgs.ark
     pkgs.appimage-run
     pkgs.kate
     pkgs.wine
     pkgs.nfs-utils
    # pkgs.xfce.thunar
     pkgs.nmap
    # pkgs.rpcbind
   ];

  # Some programs need SUID wrappers, can be configured further or are
  # started in user sessions.
  # programs.mtr.enable = true;
  # programs.gnupg.agent = {
  #   enable = true;
  #   enableSSHSupport = true;
  # };

  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  # services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
   networking.firewall.enable = false;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "21.11"; # Did you read the comment?

}

